sqlobject.inheritance.tests.test_deep_inheritance module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_deep_inheritance module

class `sqlobject.inheritance.tests.test_deep_inheritance.` `DIEmployee`(**kw)

  Bases: `sqlobject.inheritance.tests.test_deep_inheritance.DIPerson`

  classmethod `bySo_position`(val, connection=None)
  property `childName`
  property `firstName`
  `j` = di_employee
  property `lastName`
  property `manager`
  `q` = di_employee
  property `so_position`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {'DIManager': <class 'sqlobject.inheritance.tests.test_deep_inheritance.DIManager'>}
    `childName` = 'DIEmployee'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_deep_inheritance.DIPerson`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_deep_inheritance.DIEmployee`

    `table` = 'di_employee'

class `sqlobject.inheritance.tests.test_deep_inheritance.` `DIManager`(**kw)

  Bases: `sqlobject.inheritance.tests.test_deep_inheritance.DIEmployee`

  property `childName`
  `j` = di_manager
  `q` = di_manager
  property `so_position`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'DIManager'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>]
    `joins` = [<sqlobject.joins.SOMultipleJoin object>]
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_deep_inheritance.DIEmployee`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_deep_inheritance.DIManager`

    `table` = 'di_manager'
  property `subdudes`

class `sqlobject.inheritance.tests.test_deep_inheritance.` `DIPerson`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  classmethod `byLastName`(val, connection=None)
  property `childName`
  property `firstName`
  `j` = di_person
  property `lastName`
  property `manager`
  property `managerID`
  `q` = di_person
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'DIEmployee': <class 'sqlobject.inheritance.tests.test_deep_inheritance.DIEmployee'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_deep_inheritance.DIPerson`

    `table` = 'di_person'

`sqlobject.inheritance.tests.test_deep_inheritance.` `test_creation_fail`()

  Try to create a Manager without specifying a position. This should fail without leaving any partial records in the database.

`sqlobject.inheritance.tests.test_deep_inheritance.` `test_creation_fail2`()

  Try to create two Managers with the same position. This should fail without leaving any partial records in the database.

`sqlobject.inheritance.tests.test_deep_inheritance.` `test_deep_inheritance`()